@@ -96,7 +96,9 @@ def combine_with_templates(
     actions: List[Text], templates: Dict[Text, Any]
 ) -> List[Text]:
     """Combines actions with utter actions listed in responses section."""
-    unique_template_names = [a for a in list(templates.keys()) if a not in actions]
+    unique_template_names = [
+        a for a in sorted(list(templates.keys())) if a not in actions
+    ]
     return actions + unique_template_names
 
 
