@@ -203,12 +203,15 @@ class Domain:
         """Merge this domain with another one, combining their attributes.
 
         List attributes like ``intents`` and ``actions`` will be deduped
-        and merged. Single attributes will be taken from ``self`` unless
-        override is `True`, in which case they are taken from ``domain``."""
+        and merged. Single attributes will be taken from `self` unless
+        override is `True`, in which case they are taken from `domain`."""
 
-        if not domain:
+        if not domain or domain.is_empty():
             return self
 
+        if self.is_empty():
+            return domain
+
         domain_dict = domain.as_dict()
         combined = self.as_dict()
 
@@ -417,6 +420,8 @@ class Domain:
         self.templates = templates
         self.session_config = session_config
 
+        self._custom_actions = action_names
+
         # only includes custom actions and utterance actions
         self.user_actions = action.combine_with_templates(action_names, templates)
 
@@ -778,7 +783,7 @@ class Domain:
             "entities": self.entities,
             "slots": self._slot_definitions(),
             "responses": self.templates,
-            "actions": self.user_actions,  # class names of the actions
+            "actions": self._custom_actions,
             "forms": self.form_names,
         }
 
