@@ -49,6 +49,10 @@ class Exporter:
     ) -> None:
         self.endpoints_path = endpoints_path
         self.tracker_store = tracker_store
+        # The `TrackerStore` should return all events on `retrieve` and not just the
+        # ones from the last session.
+        self.tracker_store.load_events_from_previous_conversation_sessions = True
+
         self.event_broker = event_broker
         self.requested_conversation_ids = requested_conversation_ids
         self.minimum_timestamp = minimum_timestamp
@@ -136,13 +140,13 @@ class Exporter:
             return conversation_ids_in_tracker_store
 
         raise NoConversationsInTrackerStoreError(
-            f"Could not find any conversations in connected tracker store. "
-            f"Please validate your `endpoints.yml` and make sure the defined "
-            f"tracker store exists. Exiting."
+            "Could not find any conversations in connected tracker store. "
+            "Please validate your `endpoints.yml` and make sure the defined "
+            "tracker store exists. Exiting."
         )
 
     def _validate_all_requested_ids_exist(
-        self, conversation_ids_in_tracker_store: Set[Text],
+        self, conversation_ids_in_tracker_store: Set[Text]
     ) -> None:
         """Warn user if `self.requested_conversation_ids` contains IDs not found in
         `conversation_ids_in_tracker_store`
